export function getContentSelectionAmbient(editorState) {
    let selection = editorState.getSelection();
    let content = editorState.getCurrentContent();
    let leftBlockKey = selection.getStartKey();
    let leftBlock = content.getBlockForKey(leftBlockKey);
    let leftBlockText = leftBlock.getText();
    let leftOffset = selection.getStartOffset();
    let leftText = leftBlockText.slice(0, leftOffset);
    let rightBlockKey = selection.getEndKey();
    let rightBlock = content.getBlockForKey(rightBlockKey);
    let rightBlockText = rightBlock.getText();
    let rightOffset = selection.getEndOffset();
    let rightText = rightBlockText.slice(rightOffset);
    return {
        content,
        selection,
        leftOffset,
        leftBlockKey,
        leftBlock,
        leftText,
        rightOffset,
        rightBlockKey,
        rightBlock,
        rightText,
    };
}
export function setBlockDepth(content, key, depth) {
    let block = content.getBlockForKey(key);
    let blockMap = content.getBlockMap();
    block = block.merge({ depth });
    blockMap = blockMap.set(key, block);
    return content.merge({ blockMap });
}
export function characterListContainsEntityAlike(list) {
    return list.some(metadata => !!metadata.getEntity() || metadata.hasStyle('CODE'));
}
export function testCharacterListConsistency([first, ...rest]) {
    let entityKey = first.getEntity();
    let style = first.getStyle();
    for (let metadata of rest) {
        if (metadata.getEntity() !== entityKey ||
            !metadata.getStyle().equals(style)) {
            return false;
        }
    }
    return true;
}
export function getCharacterEntity(metadata, contentState) {
    let entityKey = metadata.getEntity();
    return entityKey ? contentState.getEntity(entityKey) : undefined;
}
export function getCharacterEntityType(metadata, contentState) {
    let entity = getCharacterEntity(metadata, contentState);
    return entity && entity.getType();
}
export function getCharacterEntityData(metadata, contentState) {
    let entity = getCharacterEntity(metadata, contentState);
    return entity && entity.getData();
}
export function getBlockEntityAt(block, offset, contentState) {
    let entityKey = block.getEntityAt(offset);
    return entityKey ? contentState.getEntity(entityKey) : undefined;
}
export function getBlockEntityTypeAt(block, offset, contentState) {
    let entity = getBlockEntityAt(block, offset, contentState);
    return entity && entity.getType();
}
export function getBlockEntityDataAt(block, offset, contentState) {
    let entity = getBlockEntityAt(block, offset, contentState);
    return entity && entity.getData();
}
//# sourceMappingURL=draft.js.map